Make animation of data points from spatial to UMAP space
Usage
jmv_spatial_umap_animation(seurat_object)
Arguments
- seurat_object
Spatial transcriptomics data in format of Seurat objec that contains UMAP dimensional reduction
Value
gganimate animation object
Examples
if (FALSE) {
library(jmvtools)
data <- jmvtools:::spatial_object
jmv_spatial_umap_animation(data)
}